@@ -1,4 +1,5 @@
 import asyncio
+from bergen.auths.user import User
 from typing import Dict
 from bergen.wards.graphql.aiohttp import AIOHttpGraphQLWard
 from bergen.enums import ClientType, PostmanProtocol
@@ -174,6 +175,17 @@ class BaseBergen:
 
     def negotiate(self, client_type = None):
         self.loop.run_until_complete(self.negotiate_async())
+
+
+    def getUser(self) -> User:
+        return self.auth.getUser()
+
+
+    def getExtensions(self, service):
+        assert service in self._transcript.extensions, "This Service doesnt register Extensions on Negotiate"
+        assert self._transcript.extensions[service] is not None, "There are no extensions registered for this Service and this App (see negotiate)"
+        return self._transcript.extensions[service]
+    
         
     def getWard(self) -> BaseWard:
         return self.main_ward
