@@ -15,6 +15,10 @@ class ProvisionRequestMetaExtensionsModel(MessageMetaExtensionsModel):
     progress: Optional[str]
     callback: Optional[str]
 
+    # Set by postman
+    with_progress: Optional[bool]  = False
+    with_callback: Optional[bool] = False
+
 
 class ProvisionRequestMetaModel(MessageMetaModel):
     type: str = PROVISION_REQUEST
