@@ -5,4 +5,10 @@ ALLOWANCE = "allowance"
 ASSIGNATION = "assignation"
 PROVISION = "provision"
 ASSIGNATION_REQUEST = "assignation_request"
-PROVISION_REQUEST = "provision_request"
\ No newline at end of file
+PROVISION_REQUEST = "provision_request"
+ACTIVATE_POD = "activate_pod"
+
+
+
+ASSIGN = "assign"
+CANCEL_ASSIGN = "cancel_assign"
\ No newline at end of file
